---
title: <span class="badge object-type-disjunction"></span> PipelineMetricAggregation
---
# <span class="badge object-type-disjunction"></span> PipelineMetricAggregation

## Definition

```python
PipelineMetricAggregation: typing.TypeAlias = typing.Union[elasticsearch.MovingAverage, elasticsearch.Derivative, elasticsearch.CumulativeSum, elasticsearch.BucketScript]
```
